==> freediams_0.6.0.orig.tar.gz: freediams-0.6.0/global_resources/translations/templatesplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>Templates::Internal::TemplatesContentEditor</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatescontenteditor.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templatescontenteditor.ui" line="26"/>
        <source>Content editor</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesCoreListener</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="110"/>
        <source>Save templates .</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="111"/>
        <source>Some datas are not actually saved into database.Do you want to save them ?
 Answering &apos;No&apos; will cause definitive data lose.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesCreationDialog</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="26"/>
        <source>Template creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="43"/>
        <source>User owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="57"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="67"/>
        <source>Parent category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="77"/>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="89"/>
        <source>View content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesEditDialog</name>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="26"/>
        <source>Template edition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="43"/>
        <source>User owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="50"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="57"/>
        <source>Parent category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="64"/>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="76"/>
        <source>View content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesPreferencesPage</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferencespages.cpp" line="65"/>
        <source>Templates preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesPreferencesWidget</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="20"/>
        <source>Data saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="26"/>
        <source>Always ask for confirmation before deletion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="36"/>
        <source>Presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="44"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="59"/>
        <source>Always expand categories and templates tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="73"/>
        <source>Category background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="99"/>
        <source>Category foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="151"/>
        <source>Template foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="125"/>
        <source>Template background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="14"/>
        <source>Templates preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="66"/>
        <source>Lock category view at startup</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesView</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.ui" line="28"/>
        <source>Categories tree</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::TemplateBase</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="321"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="329"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="335"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="345"/>
        <source>Please contact dev team.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::TemplatesModel</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="1025"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::TemplatesView</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="610"/>
        <source>About to delete %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="611"/>
        <source>Do you really want to remove %1 from your templates&apos; list ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="612"/>
        <source>This action is definitive and all informations will be lost. Children of this item will be deleted as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> freediams_0.6.2.orig.tar.gz: freediams-0.6.2/global_resources/translations/templatesplugin_de.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de_DE">
<context>
    <name>Templates::Internal::TemplatesContentEditor</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatescontenteditor.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templatescontenteditor.ui" line="26"/>
        <source>Content editor</source>
        <translation>Éditeur de contenu</translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesCoreListener</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="110"/>
        <source>Save templates .</source>
        <translation>Sauvegarder le modèle.</translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="111"/>
        <source>Some data are not actually saved into database.Do you want to save them ?
 Answering &apos;No&apos; will cause definitive data lose.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesCreationDialog</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="26"/>
        <source>Template creation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="43"/>
        <source>User owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="57"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="67"/>
        <source>Parent category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="77"/>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatescreationdialog.ui" line="89"/>
        <source>View content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesEditDialog</name>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="14"/>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="26"/>
        <source>Template edition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="43"/>
        <source>User owner</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="50"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="57"/>
        <source>Parent category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="64"/>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templateseditdialog.ui" line="76"/>
        <source>View content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesPreferencesPage</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferencespages.cpp" line="65"/>
        <source>Templates preferences</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesPreferencesWidget</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="20"/>
        <source>Data saving</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="26"/>
        <source>Always ask for confirmation before deletion</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="36"/>
        <source>Presentation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="44"/>
        <source>Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="59"/>
        <source>Always expand categories and templates tree</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="73"/>
        <source>Category background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="99"/>
        <source>Category foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="151"/>
        <source>Template foreground color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="125"/>
        <source>Template background color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="14"/>
        <source>Templates preferences</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatespreferenceswidget.ui" line="66"/>
        <source>Lock category view at startup</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::Internal::TemplatesView</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.ui" line="28"/>
        <source>Categories tree</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::TemplateBase</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="321"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="329"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="335"/>
        <location filename="../../plugins/templatesplugin/templatebase.cpp" line="345"/>
        <source>Please contact dev team.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::TemplatesModel</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesmodel.cpp" line="1025"/>
        <source>New</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Templates::TemplatesView</name>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="610"/>
        <source>About to delete %1.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="611"/>
        <source>Do you really want to remove %1 from your templates&apos; list ?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../../plugins/templatesplugin/templatesview.cpp" line="612"/>
        <source>This action is definitive and all information will be lost. Children of this item will be deleted as well.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
